#[repr(u8)]pub enum Samedeviceen {
INDIVIDUAL_PARALLEL = 0,
ENABLE = 1,
}Variants
INDIVIDUAL_PARALLEL = 0
In Individual mode, FLSHA1CRx/FLSHA2CRx/FLSHB1CRx/FLSHB2CRx register setting will be applied to Flash A1/A2/B1/B2 separately. In Parallel mode, FLSHA1CRx register setting will be applied to Flash A1 and B1, FLSHA2CRx register setting will be applied to Flash A2 and B2. FLSHB1CRx/FLSHB2CRx register settings will be ignored.
ENABLE = 1
FLSHA1CR0/FLSHA1CR1/FLSHA1CR2 register settings will be applied to Flash A1/A2/B1/B2. FLSHA2CRx/FLSHB1CRx/FLSHB2CRx will be ignored.
Implementations
Sourceimpl Samedeviceen
impl Samedeviceen